@@ -87,7 +87,7 @@ class EndophoraArgument(BaseArgument):
         return self.base_phrase.phrase
 
     def __repr__(self) -> str:
-        return f"{self.__class__.__name__}(base_phrase={self.base_phrase.__repr__()}, arg_type={repr(self.type)})"
+        return f"<{self.__module__}.{self.__class__.__name__}: {repr(self.base_phrase.text)}>"
 
     def __str__(self) -> str:
         return self.base_phrase.text
