@@ -1,6 +1,6 @@
 import logging
 from subprocess import PIPE, Popen, run
-from typing import Optional, Union
+from typing import List, Optional, Union
 
 from rhoknp.processors.processor import Processor
 from rhoknp.processors.senter import RegexSenter
@@ -18,23 +18,28 @@ class Jumanpp(Processor):
         senter: 文分割器のインスタンス．文分割がまだなら，先にこのインスタンスを用いて文分割する．
             未設定なら RegexSenter を使って文分割する．
 
-    Example::
+    Attributes:
+        executable: Juman++ のパス．
+        options: Juman++ のオプション．
+        senter: 文分割器のインスタンス．文分割がまだなら，先にこのインスタンスを用いて文分割する．
+            未設定なら RegexSenter を使って文分割する．
 
-        from rhoknp import Jumanpp
+    Example:
 
-        jumanpp = Jumanpp()
-        sentence = jumanpp.apply("電気抵抗率は、どんな材料が電気を通しにくいかを比較するために、用いられる物性値である。")
+        >>> from rhoknp import Jumanpp
+        <BLANKLINE>
+        >>> jumanpp = Jumanpp()
+        >>> sentence = jumanpp.apply("電気抵抗率は、どんな材料が電気を通しにくいかを比較するために、用いられる物性値である。")
     """
 
     def __init__(
         self,
         executable: str = "jumanpp",
-        options: Optional[list[str]] = None,
+        options: Optional[List[str]] = None,
         senter: Optional[Processor] = None,
-    ):
+    ) -> None:
         self.executable = executable
         self.options = options
-
         self.senter = senter
 
     def __repr__(self) -> str:
@@ -66,7 +71,7 @@ class Jumanpp(Processor):
             document = self.senter.apply_to_document(document)
 
         with Popen(self.run_command, stdout=PIPE, stdin=PIPE, encoding="utf-8") as p:
-            jumanpp_text, _ = p.communicate(input=document.to_plain())
+            jumanpp_text, _ = p.communicate(input=document.to_raw_text())
         return Document.from_jumanpp(jumanpp_text)
 
     def apply_to_sentence(self, sentence: Union[Sentence, str]) -> Sentence:
@@ -79,7 +84,7 @@ class Jumanpp(Processor):
             sentence = Sentence(sentence)
 
         with Popen(self.run_command, stdout=PIPE, stdin=PIPE, encoding="utf-8") as p:
-            jumanpp_text, _ = p.communicate(input=sentence.to_plain())
+            jumanpp_text, _ = p.communicate(input=sentence.to_raw_text())
         return Sentence.from_jumanpp(jumanpp_text)
 
     def is_available(self) -> bool:
@@ -93,7 +98,7 @@ class Jumanpp(Processor):
             return False
 
     @property
-    def run_command(self) -> list[str]:
+    def run_command(self) -> List[str]:
         """解析時に実行するコマンド．"""
         command = [self.executable]
         if self.options:
@@ -101,6 +106,6 @@ class Jumanpp(Processor):
         return command
 
     @property
-    def version_command(self) -> list[str]:
+    def version_command(self) -> List[str]:
         """バージョン確認時に実行するコマンド．"""
         return [self.executable, "-v"]
