@@ -1,6 +1,6 @@
 import logging
 from subprocess import PIPE, Popen, run
-from typing import Optional, Union
+from typing import List, Optional, Union
 
 from rhoknp.processors.jumanpp import Jumanpp
 from rhoknp.processors.processor import Processor
@@ -21,18 +21,26 @@ class KNP(Processor):
         jumanpp: Jumanpp のインスタンス．形態素解析がまだなら，先にこのインスタンスを用いて形態素解析する．
             未設定なら Jumanpp （オプションなし）を使って形態素解析する．
 
-    Example::
+    Attributes:
+        executable: KNP のパス．
+        options: KNP のオプション．
+        senter: 文分割器のインスタンス．文分割がまだなら，先にこのインスタンスを用いて文分割する．
+            未設定なら RegexSenter を使って文分割する．
+        jumanpp: Jumanpp のインスタンス．形態素解析がまだなら，先にこのインスタンスを用いて形態素解析する．
+            未設定なら Jumanpp （オプションなし）を使って形態素解析する．
 
-        from rhoknp import KNP
+    Example:
 
-        knp = KNP()
-        sentence = knp.apply("電気抵抗率は、どんな材料が電気を通しにくいかを比較するために、用いられる物性値である。")
+        >>> from rhoknp import KNP
+        <BLANKLINE>
+        >>> knp = KNP()
+        >>> sentence = knp.apply("電気抵抗率は、どんな材料が電気を通しにくいかを比較するために、用いられる物性値である。")
     """
 
     def __init__(
         self,
         executable: str = "knp",
-        options: Optional[list[str]] = None,
+        options: Optional[List[str]] = None,
         senter: Optional[Processor] = None,
         jumanpp: Optional[Processor] = None,
     ):
@@ -121,7 +129,7 @@ class KNP(Processor):
             return False
 
     @property
-    def run_command(self) -> list[str]:
+    def run_command(self) -> List[str]:
         """解析時に実行するコマンド．"""
         command = [self.executable]
         if self.options:
@@ -131,6 +139,6 @@ class KNP(Processor):
         return command
 
     @property
-    def version_command(self) -> list[str]:
+    def version_command(self) -> List[str]:
         """バージョン確認時に実行するコマンド．"""
         return [self.executable, "-v"]
