@@ -1,6 +1,6 @@
 import logging
 import re
-from typing import Union
+from typing import List, Union
 
 from rhoknp.processors.processor import Processor
 from rhoknp.units import Document, Sentence
@@ -11,27 +11,41 @@ logger = logging.getLogger(__name__)
 class RegexSenter(Processor):
     """正規表現にもとづく文分割クラス．
 
-    Example::
-        from rhoknp import RegexSenter
+    Example:
 
-        senter = RegexSenter()
-        document = senter.apply_to_document("天気が良かったので散歩した。途中で先生に会った。")
+        >>> from rhoknp import RegexSenter
+        <BLANKLINE>
+        >>> senter = RegexSenter()
+        >>> document = senter.apply_to_document("天気が良かったので散歩した。途中で先生に会った。")
     """
 
-    PERIODS = "。．？！♪☆★…?!"
+    PERIODS = "。．？！♪☆★…?!"  #: ピリオドとみなす文字．
+
+    def __repr__(self) -> str:
+        return f"{self.__class__.__name__}()"
 
     def apply_to_document(self, document: Union[Document, str]) -> Document:
+        """文書に RegexSenter を適用する．
+
+        Args:
+            document: 文書．
+        """
         if isinstance(document, str):
             document = Document(document)
         sentence_texts = self._split_document(document.text)
         return Document.from_sentences(sentence_texts)
 
     def apply_to_sentence(self, sentence: Union[Sentence, str]) -> Sentence:
+        """文に RegexSenter を適用する．
+
+        Args:
+            sentence: 文．
+        """
         if isinstance(sentence, str):
             sentence = Sentence(sentence)
         return sentence
 
-    def _split_document(self, text: str) -> list[str]:
+    def _split_document(self, text: str) -> List[str]:
         """Split text into sentences by regular expressions."""
         base = f"[^{self.PERIODS}]*[f{self.PERIODS}]"
         eol = f"[^{self.PERIODS}]*$"
@@ -42,13 +56,13 @@ class RegexSenter(Processor):
         candidates = self._merge_candidates(candidates)
         return self._clean_up_candidates(candidates)
 
-    def _merge_candidates(self, candidates: list[str]) -> list[str]:
+    def _merge_candidates(self, candidates: List[str]) -> List[str]:
         """Merge sentence candidates."""
         candidates = self._merge_single_periods(candidates)
         candidates = self._merge_parenthesis(candidates)
         return candidates
 
-    def _merge_single_periods(self, candidates: list[str]) -> list[str]:
+    def _merge_single_periods(self, candidates: List[str]) -> List[str]:
         """Merge sentence candidates that consist of just a single period."""
         regex = re.compile(f"^[{self.PERIODS}]$")
         merged_candidates = [""]
@@ -62,7 +76,7 @@ class RegexSenter(Processor):
         return merged_candidates
 
     @staticmethod
-    def _merge_parenthesis(sentence_candidates: list[str]) -> list[str]:
+    def _merge_parenthesis(sentence_candidates: List[str]) -> List[str]:
         """Merge sentence candidates so that strings in parentheses or
         brackets are not split.
         """
@@ -101,9 +115,6 @@ class RegexSenter(Processor):
         return merged_candidates
 
     @staticmethod
-    def _clean_up_candidates(sentence_candidates: list[str]) -> list[str]:
+    def _clean_up_candidates(sentence_candidates: List[str]) -> List[str]:
         """Remove empty sentence candidates."""
         return [sentence_candidate.strip() for sentence_candidate in sentence_candidates if sentence_candidate.strip()]
-
-    def __repr__(self) -> str:
-        return f"{self.__class__.__name__}()"
