@@ -1,8 +1,8 @@
 import logging
 from functools import cached_property
-from typing import TYPE_CHECKING, Optional
+from typing import TYPE_CHECKING, List, Optional
 
-from rhoknp.cohesion.discourse_relation import DiscourseRelation, DiscourseRelationList
+from rhoknp.cohesion.discourse import DiscourseRelation
 from rhoknp.units.base_phrase import BasePhrase
 from rhoknp.units.morpheme import Morpheme
 from rhoknp.units.phrase import Phrase
@@ -27,13 +27,29 @@ class Clause(Unit):
         self._sentence: Optional["Sentence"] = None
 
         # child units
-        self._phrases: Optional[list[Phrase]] = None
+        self._phrases: Optional[List[Phrase]] = None
 
-        self.discourse_relations: DiscourseRelationList = DiscourseRelationList()
+        self.discourse_relations: List[DiscourseRelation] = []  #: 談話関係のリスト．
 
-        self.index = self.count
+        self.index = self.count  #: 文内におけるインデックス．
         Clause.count += 1
 
+    def __post_init__(self) -> None:
+        super().__post_init__()
+
+        # Find discourse relations.
+        # TODO: Use forward/backward clause function
+        self.discourse_relations = []
+        for key in self.end.features:
+            if key.startswith("節-機能"):
+                if discourse_relation := DiscourseRelation.from_clause_function_fstring(key, modifier=self):
+                    self.discourse_relations.append(discourse_relation)
+        if values := self.end.features.get("談話関係", None):
+            assert isinstance(values, str)
+            for value in values.split(";"):
+                if discourse_relation := DiscourseRelation.from_discourse_relation_fstring(value, modifier=self):
+                    self.discourse_relations.append(discourse_relation)
+
     @cached_property
     def global_index(self) -> int:
         """文書全体におけるインデックス．"""
@@ -49,7 +65,7 @@ class Clause(Unit):
         return self._sentence
 
     @property
-    def child_units(self) -> Optional[list[Phrase]]:
+    def child_units(self) -> Optional[List[Phrase]]:
         """下位の言語単位（文節）．解析結果にアクセスできないなら None．"""
         return self._phrases
 
@@ -83,14 +99,14 @@ class Clause(Unit):
         self._sentence = sentence
 
     @property
-    def phrases(self) -> list[Phrase]:
+    def phrases(self) -> List[Phrase]:
         """文節のリスト．"""
         if self._phrases is None:
             raise AssertionError
         return self._phrases
 
     @phrases.setter
-    def phrases(self, phrases: list[Phrase]) -> None:
+    def phrases(self, phrases: List[Phrase]) -> None:
         """文節のリスト．
 
         Args:
@@ -101,7 +117,7 @@ class Clause(Unit):
         self._phrases = phrases
 
     @property
-    def base_phrases(self) -> list[BasePhrase]:
+    def base_phrases(self) -> List[BasePhrase]:
         """基本句のリスト．
 
         Raises:
@@ -110,7 +126,7 @@ class Clause(Unit):
         return [base_phrase for phrase in self.phrases for base_phrase in phrase.base_phrases]
 
     @property
-    def morphemes(self) -> list[Morpheme]:
+    def morphemes(self) -> List[Morpheme]:
         """形態素のリスト．
 
         Raises:
@@ -143,10 +159,15 @@ class Clause(Unit):
         return None
 
     @cached_property
-    def children(self) -> list["Clause"]:
+    def children(self) -> List["Clause"]:
         """この節に係っている節のリスト．"""
         return [clause for clause in self.sentence.clauses if clause.parent == self]
 
+    @cached_property
+    def is_adnominal(self) -> bool:
+        """連体修飾節なら True．"""
+        return self.end.features.get("節-区切", "") == "連体修飾"
+
     @classmethod
     def from_knp(cls, knp_text: str) -> "Clause":
         """節クラスのインスタンスを KNP の解析結果から初期化．
@@ -156,7 +177,7 @@ class Clause(Unit):
         """
         clause = cls()
         phrases = []
-        phrase_lines: list[str] = []
+        phrase_lines: List[str] = []
         for line in knp_text.split("\n"):
             if not line.strip():
                 continue
@@ -173,9 +194,3 @@ class Clause(Unit):
     def to_knp(self) -> str:
         """KNP フォーマットに変換．"""
         return "".join(phrase.to_knp() for phrase in self.phrases)
-
-    def parse_discourse_relation_tag(self) -> None:
-        self.discourse_relations = DiscourseRelationList()
-        for value in self.end.discourse_relation_tag.values:
-            if discourse_relation := DiscourseRelation.from_discourse_relation_tag_value(value, modifier=self):
-                self.discourse_relations.append(discourse_relation)
