@@ -1,5 +1,5 @@
 import logging
-from typing import Any, Optional, Sequence, Union
+from typing import Any, List, Optional, Sequence, Union
 
 from rhoknp.cohesion.coreference import EntityManager
 from rhoknp.cohesion.pas import Pas
@@ -31,7 +31,7 @@ class Document(Unit):
         Sentence.count = 0
 
         # child units
-        self._sentences: Optional[list[Sentence]] = None
+        self._sentences: Optional[List[Sentence]] = None
 
         if text is not None:
             self.text = text
@@ -43,27 +43,18 @@ class Document(Unit):
 
         self.entity_manager = EntityManager()
 
-    def _post_init(self) -> None:
-        """インスタンス作成後の追加処理を行う．"""
-        if self.need_senter is False:
-            for sentence in self.sentences:
-                sentence.post_init()
-        if self.need_knp is False:
-            for base_phrase in self.base_phrases:
-                base_phrase.parse_rel_tag()
-
     @property
     def parent_unit(self) -> None:
         """上位の言語単位．文書は最上位の言語単位なので常に None．"""
         return None
 
     @property
-    def child_units(self) -> Optional[list[Sentence]]:
+    def child_units(self) -> Optional[List[Sentence]]:
         """下位の言語単位（文）のリスト．解析結果にアクセスできないなら None．"""
         return self._sentences
 
     @property
-    def sentences(self) -> list[Sentence]:
+    def sentences(self) -> List[Sentence]:
         """文のリスト．
 
         Raises:
@@ -74,7 +65,7 @@ class Document(Unit):
         return self._sentences
 
     @sentences.setter
-    def sentences(self, sentences: list[Sentence]) -> None:
+    def sentences(self, sentences: List[Sentence]) -> None:
         """文のリスト．
 
         Args:
@@ -85,7 +76,7 @@ class Document(Unit):
         self._sentences = sentences
 
     @property
-    def clauses(self) -> list[Clause]:
+    def clauses(self) -> List[Clause]:
         """節のリスト．
 
         Raises:
@@ -94,7 +85,7 @@ class Document(Unit):
         return [clause for sentence in self.sentences for clause in sentence.clauses]
 
     @property
-    def phrases(self) -> list[Phrase]:
+    def phrases(self) -> List[Phrase]:
         """文節のリスト．
 
         Raises:
@@ -103,7 +94,7 @@ class Document(Unit):
         return [phrase for sentence in self.sentences for phrase in sentence.phrases]
 
     @property
-    def base_phrases(self) -> list[BasePhrase]:
+    def base_phrases(self) -> List[BasePhrase]:
         """基本句のリスト．
 
         Raises:
@@ -112,7 +103,7 @@ class Document(Unit):
         return [base_phrase for sentence in self.sentences for base_phrase in sentence.base_phrases]
 
     @property
-    def morphemes(self) -> list[Morpheme]:
+    def morphemes(self) -> List[Morpheme]:
         """形態素のリスト．
 
         Raises:
@@ -121,7 +112,7 @@ class Document(Unit):
         return [morpheme for sentence in self.sentences for morpheme in sentence.morphemes]
 
     @property
-    def named_entities(self) -> list[NamedEntity]:
+    def named_entities(self) -> List[NamedEntity]:
         """固有表現のリスト．"""
         return [ne for sentence in self.sentences for ne in sentence.named_entities]
 
@@ -145,7 +136,7 @@ class Document(Unit):
         """KNP による節-主辞・節-区切のタグ付与がまだなら True．"""
         return self.need_senter or any(sentence.need_clause_tag for sentence in self.sentences)
 
-    def pas_list(self) -> list[Pas]:
+    def pas_list(self) -> List[Pas]:
         """述語項構造のリストを返却．"""
         return [base_phrase.pas for base_phrase in self.base_phrases if base_phrase.pas is not None]
 
@@ -156,15 +147,15 @@ class Document(Unit):
         Args:
             text: 文書の生テキスト．
 
-        Example::
+        Example:
 
-            from rhoknp import Document
-
-            text = "天気が良かったので散歩した。途中で先生に会った。"
-            doc = Document.from_raw_text(text)
+            >>> from rhoknp import Document
+            <BLANKLINE>
+            >>> text = "天気が良かったので散歩した。途中で先生に会った。"
+            >>> doc = Document.from_raw_text(text)
         """
         document = cls(text.strip())
-        document._post_init()
+        document.__post_init__()
         return document
 
     @classmethod
@@ -174,24 +165,24 @@ class Document(Unit):
         Args:
             text: 一行一文形式に整形された文書のテキスト．
 
-        Example::
+        Example:
 
-            from rhoknp import Document
-
-            sents = \"\"\"
-            # S-ID:1
-            天気が良かったので散歩した。
-            # S-ID:2
-            途中で先生に会った。
-            \"\"\"
-            doc = Document.from_line_by_line_text(sents)
+            >>> from rhoknp import Document
+            <BLANKLINE>
+            >>> sents = \"\"\"
+            ... # S-ID:1
+            ... 天気が良かったので散歩した。
+            ... # S-ID:2
+            ... 途中で先生に会った。
+            ... \"\"\"
+            >>> doc = Document.from_line_by_line_text(sents)
 
         .. note::
             # から始まる行は直後の文に対するコメントとして認識される．
         """
         document = cls()
         sentences = []
-        sentence_lines: list[str] = []
+        sentence_lines: List[str] = []
         for line in text.split("\n"):
             if line.strip() == "":
                 continue
@@ -201,7 +192,7 @@ class Document(Unit):
             sentences.append(Sentence.from_raw_text("\n".join(sentence_lines), post_init=False))
             sentence_lines = []
         document.sentences = sentences
-        document._post_init()
+        document.__post_init__()
         return document
 
     @classmethod
@@ -211,12 +202,12 @@ class Document(Unit):
         Args:
             sentences: 文（文の文字列）のリスト．
 
-        Example::
+        Example:
 
-            from rhoknp import Document
-
-            sents = ["天気が良かったので散歩した。", "途中で先生に会った。"]
-            doc = Document.from_sentences(sents)
+            >>> from rhoknp import Document
+            <BLANKLINE>
+            >>> sents = ["天気が良かったので散歩した。", "途中で先生に会った。"]
+            >>> doc = Document.from_sentences(sents)
         """
         document = cls()
         sentences_ = []
@@ -233,131 +224,121 @@ class Document(Unit):
         document.sentences = sentences_
         if sentences_:
             document.doc_id = sentences_[0].doc_id
-        document._post_init()
+        document.__post_init__()
         return document
 
     @classmethod
-    def from_jumanpp(cls, jumanpp_text: str, ignore_errors: bool = False) -> "Document":
+    def from_jumanpp(cls, jumanpp_text: str) -> "Document":
         """文書クラスのインスタンスを Juman++ の解析結果から初期化．
 
         Args:
             jumanpp_text: Juman++ の解析結果．
-            ignore_errors: 解析結果中にエラーが発生してもその文を捨てて処理を続行する．
 
-        Example::
+        Example:
 
-            from rhoknp import Document
-
-            jumanpp_text = \"\"\"
-            # S-ID:1
-            天気 てんき 天気 名詞 6 普通名詞 1 * 0 * 0 "代表表記:天気/てんき カテゴリ:抽象物"
-            が が が 助詞 9 格助詞 1 * 0 * 0 NIL
-            良かった よかった 良い 形容詞 3 * 0 イ形容詞アウオ段 18 タ形 8 "代表表記:良い/よい 反義:形容詞:悪い/わるい"
-            ので ので のだ 助動詞 5 * 0 ナ形容詞 21 ダ列タ系連用テ形 12 NIL
-            散歩 さんぽ 散歩 名詞 6 サ変名詞 2 * 0 * 0 "代表表記:散歩/さんぽ ドメイン:レクリエーション カテゴリ:抽象物"
-            した した する 動詞 2 * 0 サ変動詞 16 タ形 10 "代表表記:する/する 自他動詞:自:成る/なる 付属動詞候補（基本）"
-            。 。 。 特殊 1 句点 1 * 0 * 0 NIL
-            EOS
-            # S-ID:2
-            途中 とちゅう 途中 名詞 6 時相名詞 10 * 0 * 0 "代表表記:途中/とちゅう カテゴリ:抽象物 弱時相名詞 修飾（デ格）"
-            で で で 助詞 9 格助詞 1 * 0 * 0 NIL
-            先生 せんせい 先生 名詞 6 普通名詞 1 * 0 * 0 "代表表記:先生/せんせい ドメイン:教育・学習 カテゴリ:人 人名末尾"
-            に に に 助詞 9 格助詞 1 * 0 * 0 NIL
-            会った あった 会う 動詞 2 * 0 子音動詞ワ行 12 タ形 10 "代表表記:会う/あう 反義:動詞:分かれる/わかれる;動詞:別れる/わかれる"
-            EOS
-            \"\"\"
-            doc = Document.from_jumanpp(jumanpp_text)
+            >>> from rhoknp import Document
+            <BLANKLINE>
+            >>> jumanpp_text = \"\"\"
+            ... # S-ID:1
+            ... 天気 てんき 天気 名詞 6 普通名詞 1 * 0 * 0 "代表表記:天気/てんき カテゴリ:抽象物"
+            ... が が が 助詞 9 格助詞 1 * 0 * 0 NIL
+            ... 良かった よかった 良い 形容詞 3 * 0 イ形容詞アウオ段 18 タ形 8 "代表表記:良い/よい 反義:形容詞:悪い/わるい"
+            ... ので ので のだ 助動詞 5 * 0 ナ形容詞 21 ダ列タ系連用テ形 12 NIL
+            ... 散歩 さんぽ 散歩 名詞 6 サ変名詞 2 * 0 * 0 "代表表記:散歩/さんぽ ドメイン:レクリエーション カテゴリ:抽象物"
+            ... した した する 動詞 2 * 0 サ変動詞 16 タ形 10 "代表表記:する/する 自他動詞:自:成る/なる 付属動詞候補（基本）"
+            ... 。 。 。 特殊 1 句点 1 * 0 * 0 NIL
+            ... EOS
+            ... # S-ID:2
+            ... 途中 とちゅう 途中 名詞 6 時相名詞 10 * 0 * 0 "代表表記:途中/とちゅう カテゴリ:抽象物 弱時相名詞 修飾（デ格）"
+            ... で で で 助詞 9 格助詞 1 * 0 * 0 NIL
+            ... 先生 せんせい 先生 名詞 6 普通名詞 1 * 0 * 0 "代表表記:先生/せんせい ドメイン:教育・学習 カテゴリ:人 人名末尾"
+            ... に に に 助詞 9 格助詞 1 * 0 * 0 NIL
+            ... 会った あった 会う 動詞 2 * 0 子音動詞ワ行 12 タ形 10 "代表表記:会う/あう 反義:動詞:分かれる/わかれる;動詞:別れる/わかれる"
+            ... EOS
+            ... \"\"\"
+            >>> doc = Document.from_jumanpp(jumanpp_text)
 
         .. note::
             複数文の解析結果が含まれている場合，一つの文書として扱われる．
         """
         document = cls()
         sentences = []
-        sentence_lines: list[str] = []
+        sentence_lines: List[str] = []
         for line in jumanpp_text.split("\n"):
             if line.strip() == "":
                 continue
             sentence_lines.append(line)
-            if line.strip() == Sentence.EOS:
-                try:
-                    sentences.append(Sentence.from_jumanpp("\n".join(sentence_lines) + "\n", post_init=False))
-                except Exception as e:
-                    if not ignore_errors:
-                        raise e
+            if line.strip() == Sentence.EOS_PAT:
+                sentences.append(Sentence.from_jumanpp("\n".join(sentence_lines) + "\n", post_init=False))
                 sentence_lines = []
         document.sentences = sentences
-        document._post_init()
+        document.__post_init__()
         return document
 
     @classmethod
-    def from_knp(cls, knp_text: str, ignore_errors: bool = False) -> "Document":
+    def from_knp(cls, knp_text: str) -> "Document":
         """文書クラスのインスタンスを KNP の解析結果から初期化．
 
         Args:
             knp_text: KNP の解析結果．
-            ignore_errors: 解析結果読み込み中にエラーが発生してもその文を捨てて処理を続行する．
 
         Raises:
-            Exception: ignore_errors=False かつ解析結果読み込み中にエラーが発生した場合．
+            Exception: 解析結果読み込み中にエラーが発生した場合．
 
-        Example::
+        Example:
 
-            from rhoknp import Document
-
-            knp_text = \"\"\"
-            # S-ID:1
-            * 1D
-            + 1D
-            天気 てんき 天気 名詞 6 普通名詞 1 * 0 * 0 "代表表記:天気/てんき カテゴリ:抽象物"
-            が が が 助詞 9 格助詞 1 * 0 * 0 NIL
-            * 2D
-            + 2D <節-区切><節-主辞>
-            良かった よかった 良い 形容詞 3 * 0 イ形容詞アウオ段 18 タ形 8 "代表表記:良い/よい 反義:形容詞:悪い/わるい"
-            ので ので のだ 助動詞 5 * 0 ナ形容詞 21 ダ列タ系連用テ形 12 NIL
-            * -1D
-            + -1D <節-区切><節-主辞>
-            散歩 さんぽ 散歩 名詞 6 サ変名詞 2 * 0 * 0 "代表表記:散歩/さんぽ ドメイン:レクリエーション カテゴリ:抽象物"
-            した した する 動詞 2 * 0 サ変動詞 16 タ形 10 "代表表記:する/する 自他動詞:自:成る/なる 付属動詞候補（基本）"
-            。 。 。 特殊 1 句点 1 * 0 * 0 NIL
-            EOS
-            # S-ID:2
-            * 2D
-            + 2D
-            途中 とちゅう 途中 名詞 6 時相名詞 10 * 0 * 0 "代表表記:途中/とちゅう カテゴリ:抽象物 弱時相名詞 修飾（デ格）"
-            で で で 助詞 9 格助詞 1 * 0 * 0 NIL
-            * 2D
-            + 2D
-            先生 せんせい 先生 名詞 6 普通名詞 1 * 0 * 0 "代表表記:先生/せんせい ドメイン:教育・学習 カテゴリ:人 人名末尾"
-            に に に 助詞 9 格助詞 1 * 0 * 0 NIL
-            * -1D
-            + -1D <節-区切><節-主辞>
-            会った あった 会う 動詞 2 * 0 子音動詞ワ行 12 タ形 10 "代表表記:会う/あう 反義:動詞:分かれる/わかれる;動詞:別れる/わかれる"
-            。 。 。 特殊 1 句点 1 * 0 * 0 NIL
-            EOS
-            \"\"\"
-            doc = Document.from_knp(knp_text)
+            >>> from rhoknp import Document
+            <BLANKLINE>
+            >>> knp_text = \"\"\"
+            ... # S-ID:1
+            ... * 1D
+            ... + 1D
+            ... 天気 てんき 天気 名詞 6 普通名詞 1 * 0 * 0 "代表表記:天気/てんき カテゴリ:抽象物"
+            ... が が が 助詞 9 格助詞 1 * 0 * 0 NIL
+            ... * 2D
+            ... + 2D <節-区切><節-主辞>
+            ... 良かった よかった 良い 形容詞 3 * 0 イ形容詞アウオ段 18 タ形 8 "代表表記:良い/よい 反義:形容詞:悪い/わるい"
+            ... ので ので のだ 助動詞 5 * 0 ナ形容詞 21 ダ列タ系連用テ形 12 NIL
+            ... * -1D
+            ... + -1D <節-区切><節-主辞>
+            ... 散歩 さんぽ 散歩 名詞 6 サ変名詞 2 * 0 * 0 "代表表記:散歩/さんぽ ドメイン:レクリエーション カテゴリ:抽象物"
+            ... した した する 動詞 2 * 0 サ変動詞 16 タ形 10 "代表表記:する/する 自他動詞:自:成る/なる 付属動詞候補（基本）"
+            ... 。 。 。 特殊 1 句点 1 * 0 * 0 NIL
+            ... EOS
+            ... # S-ID:2
+            ... * 2D
+            ... + 2D
+            ... 途中 とちゅう 途中 名詞 6 時相名詞 10 * 0 * 0 "代表表記:途中/とちゅう カテゴリ:抽象物 弱時相名詞 修飾（デ格）"
+            ... で で で 助詞 9 格助詞 1 * 0 * 0 NIL
+            ... * 2D
+            ... + 2D
+            ... 先生 せんせい 先生 名詞 6 普通名詞 1 * 0 * 0 "代表表記:先生/せんせい ドメイン:教育・学習 カテゴリ:人 人名末尾"
+            ... に に に 助詞 9 格助詞 1 * 0 * 0 NIL
+            ... * -1D
+            ... + -1D <節-区切><節-主辞>
+            ... 会った あった 会う 動詞 2 * 0 子音動詞ワ行 12 タ形 10 "代表表記:会う/あう 反義:動詞:分かれる/わかれる;動詞:別れる/わかれる"
+            ... 。 。 。 特殊 1 句点 1 * 0 * 0 NIL
+            ... EOS
+            ... \"\"\"
+            >>> doc = Document.from_knp(knp_text)
 
         .. note::
             複数文の解析結果が含まれている場合，一つの文書として扱われる．
         """
         document = cls()
         sentences = []
-        sentence_lines: list[str] = []
+        sentence_lines: List[str] = []
         for line in knp_text.split("\n"):
             if line.strip() == "":
                 continue
             sentence_lines.append(line)
-            if line.strip() == Sentence.EOS:
-                try:
-                    sentences.append(Sentence.from_knp("\n".join(sentence_lines) + "\n", post_init=False))
-                except Exception as e:
-                    if not ignore_errors:
-                        raise e
+            if line.strip() == Sentence.EOS_PAT:
+                sentences.append(Sentence.from_knp("\n".join(sentence_lines) + "\n", post_init=False))
                 sentence_lines = []
         document.sentences = sentences
         if sentences:
             document.doc_id = sentences[0].doc_id
-        document._post_init()
+        document.__post_init__()
         return document
 
     def reparse(self) -> "Document":
@@ -371,18 +352,18 @@ class Document(Unit):
         elif self.need_jumanpp is False:
             return Document.from_jumanpp(self.to_jumanpp())
         elif self.need_senter is False:
-            return Document.from_line_by_line_text(self.to_plain())
-        return Document.from_raw_text(self.to_plain())
+            return Document.from_line_by_line_text(self.to_raw_text())
+        return Document.from_raw_text(self.to_raw_text())
 
-    def to_plain(self) -> str:
-        """プレーンテキストフォーマットに変換．
+    def to_raw_text(self) -> str:
+        """生テキストフォーマットに変換．
 
         .. note::
             文分割済みの場合は一行一文の形式で出力．
         """
         if self.need_senter:
             return self.text.rstrip() + "\n"
-        return "".join(sentence.to_plain() for sentence in self.sentences)
+        return "".join(sentence.to_raw_text() for sentence in self.sentences)
 
     def to_jumanpp(self) -> str:
         """Juman++ フォーマットに変換．"""
