@@ -1,8 +1,8 @@
 import logging
 import re
-from typing import TYPE_CHECKING, Any, Optional, Union
+from typing import TYPE_CHECKING, Any, List, Optional, Tuple, Union
 
-from rhoknp.props.named_entity import NamedEntity, NamedEntityList
+from rhoknp.props.named_entity import NamedEntity
 from rhoknp.units.base_phrase import BasePhrase
 from rhoknp.units.clause import Clause
 from rhoknp.units.morpheme import Morpheme
@@ -23,7 +23,7 @@ class Sentence(Unit):
         text: 文の文字列．
     """
 
-    EOS = "EOS"
+    EOS_PAT = "EOS"
     SID_PAT = re.compile(r"^(?P<sid>(?P<did>[a-zA-Z\d\-_]+?)(-(\d+))?)$")
     SID_PAT_KWDLC = re.compile(r"^(?P<sid>(?P<did>w\d{6}-\d{10})(-\d+){1,2})$")
     SID_PAT_WAC = re.compile(r"^(?P<sid>(?P<did>wiki\d{8})(-\d{2})(-\d{2})?)$")
@@ -43,26 +43,31 @@ class Sentence(Unit):
         self._document: Optional["Document"] = None
 
         # child units
-        self._clauses: Optional[list[Clause]] = None
-        self._phrases: Optional[list[Phrase]] = None
-        self._morphemes: Optional[list[Morpheme]] = None
+        self._clauses: Optional[List[Clause]] = None
+        self._phrases: Optional[List[Phrase]] = None
+        self._morphemes: Optional[List[Morpheme]] = None
 
         self.sid: Optional[str] = None
         self.doc_id: Optional[str] = None
         self.misc_comment: str = ""
 
-        self.named_entities = NamedEntityList()
+        self.named_entities: List[NamedEntity] = []
 
-        self.index = self.count
+        self.index = self.count  #: 文書全体におけるインデックス．
         Sentence.count += 1
 
-    def post_init(self) -> None:
-        """インスタンス作成後の追加処理を行う．"""
+    def __post_init__(self) -> None:
+        super().__post_init__()
+
+        # Find named entities in the sentence.
+        self.named_entities = []
         if self.need_knp is False:
-            self._parse_knp_pas()
-            self._parse_ne_tags()
-        if self.need_clause_tag is False:
-            self._parse_discourse_relation()
+            for base_phrase in self.base_phrases:
+                if fstring := base_phrase.features.get("NE", None):
+                    assert isinstance(fstring, str)
+                    candidate_morphemes = self.morphemes[: base_phrase.morphemes[-1].index + 1]
+                    if named_entity := NamedEntity.from_fstring(fstring, candidate_morphemes):
+                        self.named_entities.append(named_entity)
 
     @property
     def global_index(self) -> int:
@@ -75,7 +80,7 @@ class Sentence(Unit):
         return self._document
 
     @property
-    def child_units(self) -> Optional[Union[list[Clause], list[Phrase], list[Morpheme]]]:
+    def child_units(self) -> Optional[Union[List[Clause], List[Phrase], List[Morpheme]]]:
         """下位の言語単位（節もしくは形態素）のリスト．解析結果にアクセスできないなら None．
 
         .. note::
@@ -111,7 +116,7 @@ class Sentence(Unit):
         self._document = document
 
     @property
-    def clauses(self) -> list[Clause]:
+    def clauses(self) -> List[Clause]:
         """節のリスト．
 
         Raises:
@@ -122,7 +127,7 @@ class Sentence(Unit):
         return self._clauses
 
     @clauses.setter
-    def clauses(self, clauses: list[Clause]) -> None:
+    def clauses(self, clauses: List[Clause]) -> None:
         """節のリスト．
 
         Args:
@@ -133,7 +138,7 @@ class Sentence(Unit):
         self._clauses = clauses
 
     @property
-    def phrases(self) -> list[Phrase]:
+    def phrases(self) -> List[Phrase]:
         """文節のリスト．
 
         Raises:
@@ -146,7 +151,7 @@ class Sentence(Unit):
         raise AttributeError("not available before applying KNP")
 
     @phrases.setter
-    def phrases(self, phrases: list[Phrase]) -> None:
+    def phrases(self, phrases: List[Phrase]) -> None:
         """文節のリスト．
 
         Args:
@@ -157,7 +162,7 @@ class Sentence(Unit):
         self._phrases = phrases
 
     @property
-    def base_phrases(self) -> list[BasePhrase]:
+    def base_phrases(self) -> List[BasePhrase]:
         """基本句のリスト．
 
         Raises:
@@ -166,7 +171,7 @@ class Sentence(Unit):
         return [base_phrase for phrase in self.phrases for base_phrase in phrase.base_phrases]
 
     @property
-    def morphemes(self) -> list[Morpheme]:
+    def morphemes(self) -> List[Morpheme]:
         """形態素のリスト．
 
         Raises:
@@ -181,7 +186,7 @@ class Sentence(Unit):
         raise AttributeError("not available before applying Jumanpp")
 
     @morphemes.setter
-    def morphemes(self, morphemes: list[Morpheme]) -> None:
+    def morphemes(self, morphemes: List[Morpheme]) -> None:
         """形態素のリスト．
 
         Args:
@@ -245,12 +250,12 @@ class Sentence(Unit):
             text: 文の文字列．
             post_init: インスタンス作成後の追加処理を行うなら True．
 
-        Example::
+        Example:
 
-            from rhoknp import Sentence
-
-            text = "天気が良かったので散歩した。"
-            sent = Sentence(text)
+            >>> from rhoknp import Sentence
+            <BLANKLINE>
+            >>> text = "天気が良かったので散歩した。"
+            >>> sent = Sentence(text)
         """
         sentence = cls()
         text_lines = []
@@ -263,7 +268,7 @@ class Sentence(Unit):
                 text_lines.append(line)
         sentence.text = "\n".join(text_lines)
         if post_init is True:
-            sentence.post_init()
+            sentence.__post_init__()
         return sentence
 
     @classmethod
@@ -274,26 +279,26 @@ class Sentence(Unit):
             jumanpp_text: Juman++ の解析結果．
             post_init: インスタンス作成後の追加処理を行うなら True．
 
-        Example::
+        Example:
 
-            from rhoknp import Sentence
-
-            jumanpp_text = \"\"\"
-            # S-ID:1
-            天気 てんき 天気 名詞 6 普通名詞 1 * 0 * 0 "代表表記:天気/てんき カテゴリ:抽象物"
-            が が が 助詞 9 格助詞 1 * 0 * 0 NIL
-            良かった よかった 良い 形容詞 3 * 0 イ形容詞アウオ段 18 タ形 8 "代表表記:良い/よい 反義:形容詞:悪い/わるい"
-            ので ので のだ 助動詞 5 * 0 ナ形容詞 21 ダ列タ系連用テ形 12 NIL
-            散歩 さんぽ 散歩 名詞 6 サ変名詞 2 * 0 * 0 "代表表記:散歩/さんぽ ドメイン:レクリエーション カテゴリ:抽象物"
-            した した する 動詞 2 * 0 サ変動詞 16 タ形 10 "代表表記:する/する 自他動詞:自:成る/なる 付属動詞候補（基本）"
-            。 。 。 特殊 1 句点 1 * 0 * 0 NIL
-            EOS
-            \"\"\"
-            sent = Sentence.from_jumanpp(jumanpp_text)
+            >>> from rhoknp import Sentence
+            <BLANKLINE>
+            >>> jumanpp_text = \"\"\"
+            ... # S-ID:1
+            ... 天気 てんき 天気 名詞 6 普通名詞 1 * 0 * 0 "代表表記:天気/てんき カテゴリ:抽象物"
+            ... が が が 助詞 9 格助詞 1 * 0 * 0 NIL
+            ... 良かった よかった 良い 形容詞 3 * 0 イ形容詞アウオ段 18 タ形 8 "代表表記:良い/よい 反義:形容詞:悪い/わるい"
+            ... ので ので のだ 助動詞 5 * 0 ナ形容詞 21 ダ列タ系連用テ形 12 NIL
+            ... 散歩 さんぽ 散歩 名詞 6 サ変名詞 2 * 0 * 0 "代表表記:散歩/さんぽ ドメイン:レクリエーション カテゴリ:抽象物"
+            ... した した する 動詞 2 * 0 サ変動詞 16 タ形 10 "代表表記:する/する 自他動詞:自:成る/なる 付属動詞候補（基本）"
+            ... 。 。 。 特殊 1 句点 1 * 0 * 0 NIL
+            ... EOS
+            ... \"\"\"
+            >>> sent = Sentence.from_jumanpp(jumanpp_text)
         """
         sentence = cls()
-        morphemes: list[Morpheme] = []
-        jumanpp_lines: list[str] = []
+        morphemes: List[Morpheme] = []
+        jumanpp_lines: List[str] = []
         for line in jumanpp_text.split("\n"):
             if not line.strip():
                 continue
@@ -307,11 +312,11 @@ class Sentence(Unit):
                 morphemes.append(Morpheme.from_jumanpp("\n".join(jumanpp_lines)))
                 jumanpp_lines = []
             jumanpp_lines.append(line)
-            if line.strip() == cls.EOS:
+            if line.strip() == cls.EOS_PAT:
                 break
         sentence.morphemes = morphemes
         if post_init is True:
-            sentence.post_init()
+            sentence.__post_init__()
         return sentence
 
     @classmethod
@@ -322,35 +327,35 @@ class Sentence(Unit):
             knp_text: KNP の解析結果．
             post_init: インスタンス作成後の追加処理を行うなら True．
 
-        Example::
+        Example:
 
-            from rhoknp import Sentence
-
-            knp_text = \"\"\"
-            # S-ID:1
-            * 1D
-            + 1D
-            天気 てんき 天気 名詞 6 普通名詞 1 * 0 * 0 "代表表記:天気/てんき カテゴリ:抽象物"
-            が が が 助詞 9 格助詞 1 * 0 * 0 NIL
-            * 2D
-            + 2D <節-区切><節-主辞>
-            良かった よかった 良い 形容詞 3 * 0 イ形容詞アウオ段 18 タ形 8 "代表表記:良い/よい 反義:形容詞:悪い/わるい"
-            ので ので のだ 助動詞 5 * 0 ナ形容詞 21 ダ列タ系連用テ形 12 NIL
-            * -1D
-            + -1D <節-区切><節-主辞>
-            散歩 さんぽ 散歩 名詞 6 サ変名詞 2 * 0 * 0 "代表表記:散歩/さんぽ ドメイン:レクリエーション カテゴリ:抽象物"
-            した した する 動詞 2 * 0 サ変動詞 16 タ形 10 "代表表記:する/する 自他動詞:自:成る/なる 付属動詞候補（基本）"
-            。 。 。 特殊 1 句点 1 * 0 * 0 NIL
-            EOS
-            \"\"\"
-            sent = Sentence.from_knp(knp_text)
+            >>> from rhoknp import Sentence
+            <BLANKLINE>
+            >>> knp_text = \"\"\"
+            ... # S-ID:1
+            ... * 1D
+            ... + 1D
+            ... 天気 てんき 天気 名詞 6 普通名詞 1 * 0 * 0 "代表表記:天気/てんき カテゴリ:抽象物"
+            ... が が が 助詞 9 格助詞 1 * 0 * 0 NIL
+            ... * 2D
+            ... + 2D <節-区切><節-主辞>
+            ... 良かった よかった 良い 形容詞 3 * 0 イ形容詞アウオ段 18 タ形 8 "代表表記:良い/よい 反義:形容詞:悪い/わるい"
+            ... ので ので のだ 助動詞 5 * 0 ナ形容詞 21 ダ列タ系連用テ形 12 NIL
+            ... * -1D
+            ... + -1D <節-区切><節-主辞>
+            ... 散歩 さんぽ 散歩 名詞 6 サ変名詞 2 * 0 * 0 "代表表記:散歩/さんぽ ドメイン:レクリエーション カテゴリ:抽象物"
+            ... した した する 動詞 2 * 0 サ変動詞 16 タ形 10 "代表表記:する/する 自他動詞:自:成る/なる 付属動詞候補（基本）"
+            ... 。 。 。 特殊 1 句点 1 * 0 * 0 NIL
+            ... EOS
+            ... \"\"\"
+            >>> sent = Sentence.from_knp(knp_text)
         """
         lines = knp_text.split("\n")
         sentence = cls()
         has_clause_boundary = any("節-区切" in line for line in lines if line.startswith("+"))
-        clauses: list[Clause] = []
-        phrases: list[Phrase] = []
-        child_lines: list[str] = []
+        clauses: List[Clause] = []
+        phrases: List[Phrase] = []
+        child_lines: List[str] = []
         is_clause_end = False
         for line in lines:
             if not line.strip():
@@ -362,7 +367,7 @@ class Sentence(Unit):
                 raise Exception(f"Error: {line}")
             if line.startswith("+") and "節-区切" in line:
                 is_clause_end = True
-            if line.strip() == cls.EOS:
+            if line.strip() == cls.EOS_PAT:
                 if has_clause_boundary is True:
                     clauses.append(Clause.from_knp("\n".join(child_lines)))
                 else:
@@ -382,11 +387,11 @@ class Sentence(Unit):
         else:
             sentence.phrases = phrases
         if post_init is True:
-            sentence.post_init()
+            sentence.__post_init__()
         return sentence
 
     @staticmethod
-    def _extract_sid(comment: str) -> tuple[Optional[str], Optional[str], str]:
+    def _extract_sid(comment: str) -> Tuple[Optional[str], Optional[str], str]:
         """Extract sentence id and document id from comment line.
 
         Args:
@@ -414,8 +419,8 @@ class Sentence(Unit):
         assert comment.startswith("# ")
         return None, None, comment[2:]
 
-    def to_plain(self) -> str:
-        """プレーンテキストフォーマットに変換．"""
+    def to_raw_text(self) -> str:
+        """生テキストフォーマットに変換．"""
         ret = ""
         if self.comment != "":
             ret += self.comment + "\n"
@@ -427,7 +432,7 @@ class Sentence(Unit):
         ret = ""
         if self.comment != "":
             ret += self.comment + "\n"
-        ret += "".join(morpheme.to_jumanpp() for morpheme in self.morphemes) + self.EOS + "\n"
+        ret += "".join(morpheme.to_jumanpp() for morpheme in self.morphemes) + self.EOS_PAT + "\n"
         return ret
 
     def to_knp(self) -> str:
@@ -436,7 +441,7 @@ class Sentence(Unit):
         if self.comment != "":
             ret += self.comment + "\n"
         ret += "".join(child.to_knp() for child in self._clauses or self.phrases)
-        ret += self.EOS + "\n"
+        ret += self.EOS_PAT + "\n"
         return ret
 
     def reparse(self) -> "Sentence":
@@ -449,28 +454,7 @@ class Sentence(Unit):
             return Sentence.from_knp(self.to_knp())
         elif self.need_jumanpp is False:
             return Sentence.from_jumanpp(self.to_jumanpp())
-        return Sentence.from_raw_text(self.to_plain())
-
-    def _parse_knp_pas(self) -> None:
-        """KNP 解析結果における <述語項構造> タグおよび <格解析結果> タグをパース．"""
-        for base_phrase in self.base_phrases:
-            base_phrase.parse_pas_tag()
-
-    def _parse_ne_tags(self) -> None:
-        """<NE> タグをパースし，固有表現オブジェクトを作成．"""
-        named_entities = []
-        candidate_morphemes = []
-        for base_phrase in self.base_phrases:
-            candidate_morphemes += base_phrase.morphemes
-            for ne_tag in base_phrase.ne_tags:
-                if named_entity := NamedEntity.from_ne_tag(ne_tag, candidate_morphemes):
-                    named_entities.append(named_entity)
-        self.named_entities = NamedEntityList(named_entities)
-
-    def _parse_discourse_relation(self) -> None:
-        """<談話関係> タグをパース．"""
-        for clause in self.clauses:
-            clause.parse_discourse_relation_tag()
+        return Sentence.from_raw_text(self.to_raw_text())
 
     def __eq__(self, other: Any) -> bool:
         if isinstance(other, Sentence) is False:
